yaml-parser.reader


buffer-slotclj/s

source

byte-offsetclj/s

(byte-offset reader)
source

byte-offset-slotclj/s

source

cache-codepoint-slotclj/s

source

cache-position-slotclj/s

source

cache-width-slotclj/s

source

codepoint-stringclj/s

(codepoint-string value)
source

columnclj/s

(column reader)
source

column-slotclj/s

source

end-slotclj/s

source

eof?clj/s

(eof? reader)
source

forward!clj/s

(forward! reader)

Advance by one non-line-break code point and return that code point.

Advance by one non-line-break code point and return that code point.
sourceraw docstring

forward-flow-run!clj/s

(forward-flow-run! reader quote single?)

Advance over one contiguous non-blank quoted-scalar segment.

Advance over one contiguous non-blank quoted-scalar segment.
sourceraw docstring

forward-line!clj/s

(forward-line! reader)

Consume one YAML line break and return its normalized string value.

Consume one YAML line break and return its normalized string value.
sourceraw docstring

forward-line-run!clj/s

(forward-line-run! reader)

Advance over a non-line-break scalar/comment segment in one state update.

Advance over a non-line-break scalar/comment segment in one state update.
sourceraw docstring

forward-plain-run!clj/s

(forward-plain-run! reader flow?)

Advance over one contiguous non-blank plain-scalar segment.

Advance over one contiguous non-blank plain-scalar segment.
sourceraw docstring

index-slotclj/s

source

inputclj/s

(input reader)
source

input-slotclj/s

source

lineclj/s

(line reader)
source

line-break?clj/s

(line-break? value)
source

line-slotclj/s

source

make-readerclj/s

(make-reader input)

Create a reader over a YAML string. nil is treated as an empty string.

Create a reader over a YAML string. nil is treated as an empty string.
sourceraw docstring

markclj/s

(mark reader)
source

peek-atclj/s

(peek-at reader offset)

Return the code point offset characters ahead, or zero past EOF.

Return the code point `offset` characters ahead, or zero past EOF.
sourceraw docstring

peek-codepointclj/s

(peek-codepoint reader)

Return the current code point, or zero at end of input.

Return the current code point, or zero at end of input.
sourceraw docstring

positionclj/s

(position reader)
source

position-slotclj/s

source

sliceclj/s

(slice reader start end)

Return the original input slice between two raw reader positions.

Return the original input slice between two raw reader positions.
sourceraw docstring

slice-offset-slotclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries